#define INCL_DOS
#define INCL_WIN
#define INCL_MCIOS2
#define INCL_MACHDR

#include <os2.h>
#include <os2me.h>
#include "oscardata.h"
#include "oscarsession.h"

static ULONG (EXPENTRY *pMciPlayFile) ( HWND hwndOwner, PSZ pszFile,
 ULONG ulFlags, PSZ pszTitle, HWND hwndViewPort ) = NULL;

static HMODULE mciDLL = 0;

void initializeCompatibility( int initMMPM )
{
  ULONG rc;
  
  if ( !initMMPM )
  {
    debugf( "Sound was disabled by a user command line option.\n" );
  } else {
    rc = DosLoadModule( NULL, 0, "MCIAPI.DLL", &mciDLL );
    if ( rc == 0 )
    {
      rc = DosQueryProcAddr( mciDLL, 10, NULL, (PFN *) &pMciPlayFile );
      debugf( "Multimedia Control Interface was initialized at runtime.\n" );
    }
    
    if ( rc )
    {
      debugf( "Unable to load Multimedia Control Interface.\n" );
      debugf( "Sound will be disabled as a result.\n" );
    }
  }
}

void deinitializeCompatibility( void )
{
  DosFreeModule( mciDLL );
  pMciPlayFile = NULL;
}

int isMultiMediaCapable( void )
{
  return pMciPlayFile != NULL;
}

ULONG rtMciPlayFile( HWND hwndOwner, PSZ pszFile, ULONG ulFlags,
 PSZ pszTitle, HWND hwndViewPort )
{
  if ( pMciPlayFile )
  {
    return (*pMciPlayFile)( hwndOwner, pszFile, ulFlags, pszTitle,
     hwndViewPort );
  }
  return 0;
}

void handleMrMessageEvent( UI_EventType eventType,
 sessionThreadSettings *specificSettings,
 sessionThreadSettings *globalSettings, int asynchronous )
{
  sessionThreadSettings *theSettings;
  
  if ( !specificSettings || specificSettings->inheritSettings )
    theSettings = globalSettings;
  else
    theSettings = specificSettings;
  
  if ( theSettings->settingFlags[ eventType ] & SET_SOUND_ENABLED )
  {
    rtMciPlayFile( HWND_DESKTOP, theSettings->sounds[ eventType ],
     asynchronous ? MCI_ASYNC : MCI_ASYNCRENDEZVOUS, NULL, NULLHANDLE );
  }
  
  // Handle REXX and shell script launching here too...
}

unsigned long testSettingsFlag( unsigned long theFlag,
 sessionThreadSettings *specificSettings,
 sessionThreadSettings *globalSettings )
{
  sessionThreadSettings *theSettings;
  
  if ( !specificSettings || specificSettings->inheritSettings )
    theSettings = globalSettings;
  else
    theSettings = specificSettings;
  
  return theSettings->sessionFlags & theFlag;
}

